cef/patch/patches/services_network_2622.patch
2025-03-12 13:05:48 -04:00

143 lines
6.1 KiB
Diff

diff --git net/cookies/cookie_monster.cc net/cookies/cookie_monster.cc
index cd7ce8c483362..4e05ca9aa5896 100644
--- net/cookies/cookie_monster.cc
+++ net/cookies/cookie_monster.cc
@@ -681,6 +681,25 @@ void CookieMonster::SetCookieableSchemes(
MaybeRunCookieCallback(std::move(callback), true);
}
+void CookieMonster::AddCookieableSchemes(
+ const std::vector<std::string>& schemes,
+ SetCookieableSchemesCallback callback) {
+ DCHECK_CALLED_ON_VALID_THREAD(thread_checker_);
+
+ // Calls to this method will have no effect if made after a WebView or
+ // CookieManager instance has been created.
+ if (initialized_) {
+ MaybeRunCookieCallback(std::move(callback), false);
+ return;
+ }
+
+ if (!schemes.empty()) {
+ cookieable_schemes_.insert(cookieable_schemes_.begin(), schemes.begin(),
+ schemes.end());
+ }
+ MaybeRunCookieCallback(std::move(callback), true);
+}
+
// This function must be called before the CookieMonster is used.
void CookieMonster::SetPersistSessionCookies(bool persist_session_cookies) {
DCHECK_CALLED_ON_VALID_THREAD(thread_checker_);
diff --git net/cookies/cookie_monster.h net/cookies/cookie_monster.h
index 18fed025ee0b2..8d7ed64030ad1 100644
--- net/cookies/cookie_monster.h
+++ net/cookies/cookie_monster.h
@@ -239,6 +239,8 @@ class NET_EXPORT CookieMonster : public CookieStore {
CookieChangeDispatcher& GetChangeDispatcher() override;
void SetCookieableSchemes(const std::vector<std::string>& schemes,
SetCookieableSchemesCallback callback) override;
+ void AddCookieableSchemes(const std::vector<std::string>& schemes,
+ SetCookieableSchemesCallback callback) override;
std::optional<bool> SiteHasCookieInOtherPartition(
const net::SchemefulSite& site,
const std::optional<CookiePartitionKey>& partition_key) const override;
diff --git net/cookies/cookie_store.h net/cookies/cookie_store.h
index 7c76c93f798b2..09f62ad48ccb4 100644
--- net/cookies/cookie_store.h
+++ net/cookies/cookie_store.h
@@ -171,6 +171,11 @@ class NET_EXPORT CookieStore {
// Transfer ownership of a CookieAccessDelegate.
void SetCookieAccessDelegate(std::unique_ptr<CookieAccessDelegate> delegate);
+ // Adds to the list of cookieable schemes. Does nothing if called after first
+ // use of the instance (i.e. after the instance initialization process).
+ virtual void AddCookieableSchemes(const std::vector<std::string>& schemes,
+ SetCookieableSchemesCallback callback) = 0;
+
// This may be null if no delegate has been set yet, or the delegate has been
// reset to null.
const CookieAccessDelegate* cookie_access_delegate() const {
diff --git services/network/cookie_manager.cc services/network/cookie_manager.cc
index 95f73bcb9fb40..e17a93f69c089 100644
--- services/network/cookie_manager.cc
+++ services/network/cookie_manager.cc
@@ -355,14 +355,9 @@ void CookieManager::AllowFileSchemeCookies(
AllowFileSchemeCookiesCallback callback) {
OnSettingsWillChange();
- std::vector<std::string> cookieable_schemes(
- net::CookieMonster::kDefaultCookieableSchemes,
- net::CookieMonster::kDefaultCookieableSchemes +
- net::CookieMonster::kDefaultCookieableSchemesCount);
- if (allow) {
- cookieable_schemes.push_back(url::kFileScheme);
- }
- cookie_store_->SetCookieableSchemes(cookieable_schemes, std::move(callback));
+ if (!allow)
+ return;
+ cookie_store_->AddCookieableSchemes({url::kFileScheme}, std::move(callback));
}
void CookieManager::SetForceKeepSessionState() {
diff --git services/network/public/mojom/network_context.mojom services/network/public/mojom/network_context.mojom
index be45c88ba8571..536e92b4e9497 100644
--- services/network/public/mojom/network_context.mojom
+++ services/network/public/mojom/network_context.mojom
@@ -360,6 +360,9 @@ struct NetworkContextParams {
// cookies. Otherwise it should be false.
bool persist_session_cookies = false;
+ // Schemes that will be passed to CookieMonster::SetCookieableSchemes.
+ array<string>? cookieable_schemes;
+
// True if an HTTP cache should be used.
bool http_cache_enabled = true;
// Maximum size of the HTTP cache. 0 means to use the default size.
diff --git services/network/network_context.cc services/network/network_context.cc
index ca2df1e67d756..d2e963efdf1d8 100644
--- services/network/network_context.cc
+++ services/network/network_context.cc
@@ -2785,22 +2785,26 @@ URLRequestContextOwner NetworkContext::MakeURLRequestContext(
pref_service.get(), network_service_->network_quality_estimator());
}
- if (session_cleanup_cookie_store) {
- // If the pref service was registered and initialized use it.
- // If not, use nullptr to indicate prefs aren't available.
- std::unique_ptr<net::CookieMonster> cookie_store =
- std::make_unique<net::CookieMonster>(
- session_cleanup_cookie_store.get(), net_log,
- pref_service
- ? std::make_unique<KnownLegacyScopeDomainsPrefDelegate>(
- pref_service.get())
- : nullptr);
- if (params_->persist_session_cookies) {
- cookie_store->SetPersistSessionCookies(true);
- }
-
- builder.SetCookieStore(std::move(cookie_store));
- }
+ // If the pref service was registered and initialized use it.
+ // If not, use nullptr to indicate prefs aren't available.
+ std::unique_ptr<net::CookieMonster> cookie_store =
+ std::make_unique<net::CookieMonster>(
+ session_cleanup_cookie_store.get(), net_log,
+ pref_service
+ ? std::make_unique<KnownLegacyScopeDomainsPrefDelegate>(
+ pref_service.get())
+ : nullptr);
+ if (session_cleanup_cookie_store && params_->persist_session_cookies) {
+ cookie_store->SetPersistSessionCookies(true);
+ }
+
+ if (params_->cookieable_schemes.has_value()) {
+ cookie_store->SetCookieableSchemes(
+ *params_->cookieable_schemes,
+ net::CookieStore::SetCookieableSchemesCallback());
+ }
+
+ builder.SetCookieStore(std::move(cookie_store));
base::FilePath transport_security_persister_file_name;
if (GetFullDataFilePath(params_->file_paths,